/*
  exampleGroupPosControl_MEGA
  Drives group of HerkuleX servos thanks to the HerkuleXLib (see 
  www.benoitpuel.com/blog/telechargements/) using an Arduino MEGA board.

  The serial terminal is used to printout messages.

  This example code is in the public domain.

  modified 10 February 2016
  by Benoit Puel
 */

#include <HkxGroupPosControl.h>

void setup() {
  // INPUT
  const byte nbServos = 3;
  byte IDs[nbServos] = {0, 1, 2};

  delay(5000); // wait 5 seconds to open the serial monitor
  HkxPrint printoutLib = HkxPrint(Serial, 9600);  // Printout errors on the serial monitor
  HkxPrint printoutCode = HkxPrint(printoutLib, true, true, true);  // Printout errors on the serial monitor
  HkxCommunication communication = HkxCommunication(HKX_666666, Serial1, printoutLib);  // Communication with the servo on Serial1
  HkxPosControl servo0 = HkxPosControl(IDs[0], communication, printoutLib);
  HkxPosControl servo1 = HkxPosControl(IDs[1], communication, printoutLib);
  HkxPosControl servo2 = HkxPosControl(IDs[2], communication, printoutLib);
  HkxPosControl* arrayServos[nbServos] = {&servo0, &servo1, &servo2};
  HkxGroupPosControl HerkGroupServo = HkxGroupPosControl(nbServos, arrayServos, printoutLib);

  // Set the torque to free and the LED off
  HerkGroupServo.setAllTorqueLEDControl(HKX_TORQUE_FREE, HKX_LED_OFF);
  delay(5000); // wait 5 seconds

  // Set the torque to break and the LED to yellow
  HerkGroupServo.setAllTorqueLEDControl(HKX_TORQUE_BREAK, HKX_LED_YELLOW);
  printoutCode.infoPrint("Torque is break, LED is yellow");
  delay(5000); // wait 5 seconds

  // Move servos to positions {45°, 30°, 15°} in 2 seconds, leds turned to pink,
  // wait for the end of the move
  printoutCode.infoPrint("Start moving to 45°, 30° and 15° in 2 seconds, pink LED");
  int16_t tabPos[] = {450, 300, 150};
  HkxMaybe<hkxLEDControl> tabLed[] = {HKX_LED_PINK, HKX_LED_PINK, HKX_LED_PINK};
  HerkGroupServo.moveSyncAllPosition(tabPos, 2000, tabLed, true); 
  printoutCode.infoPrint("The move is finished, torque is break and LED back to yellow");
  delay(5000); // wait 5 seconds

  // Move servos to positions {-45°, -30°, -15°} in 2, 1, 0.5 seconds, leds turned to pink,
  // wait for the end of the move
  printoutCode.infoPrint("Start moving to -45°, -30° and -15° in 2, 1, .5 seconds, pink LED");
  int16_t tabPos2[] = {-450, -300, -150};
  uint16_t tabTime[] = {2000, 1000, 500};
  HerkGroupServo.moveAsyncAllPosition(tabPos2, tabTime, tabLed, true); 
  printoutCode.infoPrint("The move is finished, torque is break and LED back to yellow");
}

void loop() {
  // put your main code here, to run repeatedly:

}
