/*
  modifyID_MEGA
  Modifies the ID value of a HerkuleX servo thanks to the HerkuleXLib
  (see www.benoitpuel.com/blog/telechargements/) using an Arduino MEGA 
  board.

  The serial terminal is used to printout messages.

  This example code is in the public domain.

  modified 9 February 2016
  by Benoit Puel
 */
 
#include <HkxSetup.h>

void setup() {
  delay(5000); // wait 5 seconds to open the serial monitor
  HkxPrint printoutLib = HkxPrint(Serial, 9600);  // Printout errors on the serial monitor
  HkxPrint printoutCode = HkxPrint(printoutLib, true, true, true);  // Printout errors on the serial monitor
  HkxCommunication communication = HkxCommunication(HKX_115200, Serial1, printoutLib);  // Communication with the servo on Serial1
  HkxSetup setupServos(communication, printoutLib);  // setup the servos

  // VALUES TO BE MODIFIED
  byte currentID = 253; // current value of servo ID [0 ; 254]
  byte newID = 2; // new ID value to apply to the servo [0 ; 254]

  // variables
  HkxStatus statusED;
  byte err = 0;

  // check the currentID is connected
  err = setupServos.getStatus (currentID, statusED);
  if(err != 0){ 
    printoutCode.errorPrint("The servo is not connected");
    return;
  }

  // change the ID
  err = setupServos.setID(currentID, newID);
  if(err != 0){ // check if newID already used
    printoutCode.errorPrint("newID is already used");
    return;
  }

  // check the change has been correctly performed
  err = setupServos.getStatus (newID, statusED);
  if(err != 0){ 
    printoutCode.errorPrint("ID modification did not performed correctly");
    return;
  }
  printoutCode.infoPrint("ID modified :)");
}

void loop() {
  // put your main code here, to run repeatedly:

}
