/*
  modifyID_UNO
  Modifies the ID value of a HerkuleX servo thanks to the HerkuleXLib
  (see www.benoitpuel.com/blog/telechargements/) using an Arduino UNO 
  board.

  The LED of the board is turned on during the process then turned off 
  when process went correctly. Otherwise LED is blinking if an error 
  occured.

  This example code is in the public domain.

  modified 9 February 2016
  by Benoit Puel
 */
 
#include <HkxSetup.h>

byte err = 0;

void setup() {
  // turns on the LED during the process
  pinMode(13, OUTPUT);
  digitalWrite(13, HIGH);
  
  HkxPrint printout = HkxPrint();  // No printout with Arduino UNO
  HkxCommunication communication = HkxCommunication(HKX_115200, Serial1, printout);  // Communication with the servo on Serial1
  HkxSetup setupServos(communication, printout);  // setup the servos

  // VALUES TO BE MODIFIED
  byte currentID = 253; // current value of servo ID
  byte newID = 2; // new ID value to apply to the servo

  // variable
  HkxStatus statusED;

  // check the currentID is connected
  err = setupServos.getStatus (currentID, statusED);
  if(err != 0){ 
    return;
  }

  // change the ID
  err = setupServos.setID(currentID, newID);
  if(err != 0){ // check if newID already used
    return;
  }

  // check the change has been correctly performed
  err = setupServos.getStatus (newID, statusED);
  if(err != 0){ 
    return;
  }

  // turns off the LED when process went correctly
  digitalWrite(13, LOW);
}

void loop() {
  if(err != 0){ // LED blinking if an error occured
    digitalWrite(13, HIGH);
    delay(1000);
    digitalWrite(13, LOW);
    delay(1000);
  }
}
